Struct spandex::layout::paragraphs::items::PositionedItem[][src]

pub struct PositionedItem<'a> {
    pub index: usize,
    pub line: usize,
    pub horizontal_offset: Pt,
    pub width: Pt,
    pub glyph: Glyph<'a>,
}
Holds the information of an item that’s ready to be rendered.

Fields

index: usize

The index of the item within the list of items that make up the paragraph in which is stands.

line: usize

The index of the line on which this item is to be rendered.

horizontal_offset: Pt

The horizontal offset of the item.

width: Pt

The (potentially adjusted) width this item should be rendered with.

glyph: Glyph<'a>

The glyph that should be layed out within this item.